=== modified file 'bzrlib/bugtracker.py'
--- bzrlib/bugtracker.py	2009-03-12 07:06:18 +0000
+++ bzrlib/bugtracker.py	2009-03-12 07:35:17 +0000
@@ -286,6 +286,8 @@
 
 FIXED = 'fixed'
 
+ALLOWED_BUG_STATUSES = set([FIXED])
+
 
 def encode_fixes_bug_urls(bug_urls):
     """Return the 'bugs' property value for a revision that fixes 'bug_urls'.

=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2009-03-11 10:22:00 +0000
+++ bzrlib/errors.py	2009-03-12 07:35:17 +0000
@@ -2532,6 +2532,22 @@
         self.branch = branch
 
 
+class InvalidLineInBugsProperty(BzrError):
+
+    _fmt = ("Invalid line in bugs property: '%(line)s'")
+
+    def __init__(self, line):
+        self.line = line
+
+
+class InvalidBugStatus(BzrError):
+
+    _fmt = ("Invalid bug status: '%(status)s'")
+
+    def __init__(self, status):
+        self.status = status
+
+
 class UnexpectedSmartServerResponse(BzrError):
 
     _fmt = "Could not understand response from smart server: %(response_tuple)r"

=== modified file 'bzrlib/revision.py'
--- bzrlib/revision.py	2009-02-27 15:14:34 +0000
+++ bzrlib/revision.py	2009-03-12 07:35:17 +0000
@@ -21,6 +21,7 @@
 from bzrlib.lazy_import import lazy_import
 lazy_import(globals(), """
 from bzrlib import deprecated_graph
+from bzrlib import bugtracker
 """)
 from bzrlib import (
     errors,
@@ -140,6 +141,20 @@
         else:
             return authors.split("\n")
 
+    def iter_bugs(self):
+        """Iterate over the bugs associated with this revision."""
+        bug_property = self.properties.get('bugs', None)
+        if bug_property is None:
+            return
+        for line in bug_property.splitlines():
+            try:
+                url, status = line.split(None, 2)
+            except ValueError:
+                raise errors.InvalidLineInBugsProperty(line)
+            if status not in bugtracker.ALLOWED_BUG_STATUSES:
+                raise errors.InvalidBugStatus(status)
+            yield url, status
+
 
 def iter_ancestors(revision_id, revision_source, only_present=False):
     ancestors = (revision_id,)

=== modified file 'bzrlib/tests/test_revision.py'
--- bzrlib/tests/test_revision.py	2009-02-27 15:14:34 +0000
+++ bzrlib/tests/test_revision.py	2009-03-12 07:35:17 +0000
@@ -19,11 +19,16 @@
 import warnings
 
 from bzrlib import (
+    bugtracker,
     revision,
     symbol_versioning,
     )
 from bzrlib.branch import Branch
-from bzrlib.errors import NoSuchRevision
+from bzrlib.errors import (
+    InvalidBugStatus,
+    InvalidLineInBugsProperty,
+    NoSuchRevision,
+    )
 from bzrlib.deprecated_graph import Graph
 from bzrlib.revision import (find_present_ancestors,
                              NULL_REVISION)
@@ -231,3 +236,37 @@
         self.assertEqual(['B'], r.get_apparent_authors())
         r.properties['authors'] = 'C\nD'
         self.assertEqual(['C', 'D'], r.get_apparent_authors())
+
+
+class TestRevisionBugs(TestCase):
+    """Tests for getting the bugs that a revision is linked to."""
+
+    def test_no_bugs(self):
+        r = revision.Revision('1')
+        self.assertEqual([], list(r.iter_bugs()))
+
+    def test_some_bugs(self):
+        r = revision.Revision(
+            '1', properties={
+                'bugs': bugtracker.encode_fixes_bug_urls(
+                    ['http://example.com/bugs/1',
+                     'http://launchpad.net/bugs/1234'])})
+        self.assertEqual(
+            [('http://example.com/bugs/1', bugtracker.FIXED),
+             ('http://launchpad.net/bugs/1234', bugtracker.FIXED)],
+            list(r.iter_bugs()))
+
+    def test_no_status(self):
+        r = revision.Revision(
+            '1', properties={'bugs': 'http://example.com/bugs/1'})
+        self.assertRaises(InvalidLineInBugsProperty, list, r.iter_bugs())
+
+    def test_too_much_information(self):
+        r = revision.Revision(
+            '1', properties={'bugs': 'http://example.com/bugs/1 fixed bar'})
+        self.assertRaises(InvalidLineInBugsProperty, list, r.iter_bugs())
+
+    def test_invalid_status(self):
+        r = revision.Revision(
+            '1', properties={'bugs': 'http://example.com/bugs/1 faxed'})
+        self.assertRaises(InvalidBugStatus, list, r.iter_bugs())

